Struct dashmap::DashSet [−][src]
pub struct DashSet<K, S = RandomState> { /* fields omitted */ }Expand description
DashSet is a thin wrapper around DashMap using () as the value type. It uses
methods and types which are more convenient to work with on a set.
Implementations
Creates a new DashMap with a capacity of 0 and the provided hasher.
Examples
use dashmap::DashSet;
use std::collections::hash_map::RandomState;
let s = RandomState::new();
let games = DashSet::with_hasher(s);
games.insert("Veloren");Creates a new DashMap with a specified starting capacity and hasher.
Examples
use dashmap::DashSet;
use std::collections::hash_map::RandomState;
let s = RandomState::new();
let numbers = DashSet::with_capacity_and_hasher(2, s);
numbers.insert(2);
numbers.insert(8);Hash a given item to produce a usize. Uses the provided or default HashBuilder.
Inserts a key into the set. Returns true if the key was not already in the set.
Examples
use dashmap::DashSet;
let set = DashSet::new();
set.insert("I am the key!");Removes an entry from the map, returning the key if it existed in the map.
Examples
use dashmap::DashSet;
let soccer_team = DashSet::new();
soccer_team.insert("Jack");
assert_eq!(soccer_team.remove("Jack").unwrap(), "Jack");Removes an entry from the set, returning the key if the entry existed and the provided conditional function returned true.
use dashmap::DashSet;
let soccer_team = DashSet::new();
soccer_team.insert("Sam");
soccer_team.remove_if("Sam", |player| player.starts_with("Ja"));
assert!(soccer_team.contains("Sam"));use dashmap::DashSet;
let soccer_team = DashSet::new();
soccer_team.insert("Sam");
soccer_team.remove_if("Jacob", |player| player.starts_with("Ja"));
assert!(!soccer_team.contains("Jacob"));Creates an iterator over a DashMap yielding immutable references.
Examples
use dashmap::DashSet;
let words = DashSet::new();
words.insert("hello");
assert_eq!(words.iter().count(), 1);Get a reference to an entry in the set
Examples
use dashmap::DashSet;
let youtubers = DashSet::new();
youtubers.insert("Bosnian Bill");
assert_eq!(*youtubers.get("Bosnian Bill").unwrap(), "Bosnian Bill");Remove excess capacity to reduce memory usage.
Retain elements that whose predicates return true and discard elements whose predicates return false.
Examples
use dashmap::DashSet;
let people = DashSet::new();
people.insert("Albin");
people.insert("Jones");
people.insert("Charlie");
people.retain(|name| name.contains('i'));
assert_eq!(people.len(), 2);Fetches the total number of keys stored in the set.
Examples
use dashmap::DashSet;
let people = DashSet::new();
people.insert("Albin");
people.insert("Jones");
people.insert("Charlie");
assert_eq!(people.len(), 3);Checks if the set is empty or not.
Examples
use dashmap::DashSet;
let map = DashSet::<()>::new();
assert!(map.is_empty());Removes all keys in the set.
Examples
use dashmap::DashSet;
let people = DashSet::new();
people.insert("Albin");
assert!(!people.is_empty());
people.clear();
assert!(people.is_empty());Trait Implementations
Extends a collection with the contents of an iterator. Read more
extend_one)Extends a collection with exactly one element.
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Creates a value from an iterator. Read more