Struct dashmap::ReadOnlyView [−][src]
pub struct ReadOnlyView<K, V, S = RandomState> { /* fields omitted */ }Expand description
A read-only view into a DashMap. Allows to obtain raw references to the stored values.
Implementations
Consumes this ReadOnlyView, returning the underlying DashMap.
Returns the number of elements the map can hold without reallocating.
Returns true if the map contains a value for the specified key.
Returns a reference to the value corresponding to the key.
Returns the key-value pair corresponding to the supplied key.
An iterator visiting all key-value pairs in arbitrary order. The iterator element type is (&'a K, &'a V).
An iterator visiting all keys in arbitrary order. The iterator element type is &'a K.